==> ng2-bootstrap-1.0.24.jar: META-INF/resources/webjars/ng2-bootstrap/1.0.24/components/typeahead/typeahead.directive.d.ts <==
import { EventEmitter, OnInit, ElementRef, Renderer, DynamicComponentLoader, ViewContainerRef } from '@angular/core';
import { NgControl } from '@angular/forms';
import { TypeaheadContainerComponent } from './typeahead-container.component';
import 'rxjs/add/observable/from';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/filter';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/mergeMap';
import 'rxjs/add/operator/toArray';
export declare class TypeaheadDirective implements OnInit {
    typeaheadLoading: EventEmitter<boolean>;
    typeaheadNoResults: EventEmitter<boolean>;
    typeaheadOnSelect: EventEmitter<{
        item: any;
    }>;
    typeahead: any;
    typeaheadMinLength: number;
    typeaheadWaitMs: number;
    typeaheadOptionsLimit: number;
    typeaheadOptionField: string;
    typeaheadAsync: boolean;
    typeaheadLatinize: boolean;
    typeaheadSingleWords: boolean;
    typeaheadWordDelimiters: string;
    typeaheadPhraseDelimiters: string;
    container: TypeaheadContainerComponent;
    isTypeaheadOptionsListActive: boolean;
    private keyUpEventEmitter;
    private _matches;
    private placement;
    private popup;
    private ngControl;
    private viewContainerRef;
    private element;
    private renderer;
    private loader;
    protected onChange(e: any): void;
    protected onFocus(): void;
    protected onBlur(): void;
    protected onKeydown(e: KeyboardEvent): void;
    constructor(control: NgControl, viewContainerRef: ViewContainerRef, element: ElementRef, renderer: Renderer, loader: DynamicComponentLoader);
    ngOnInit(): void;
    changeModel(value: any): void;
    matches: Array<any>;
    show(matches: Array<any>): void;
    hide(): void;
    private asyncActions();
    private syncActions();
    private prepareOption(option);
    private normalizeQuery(value);
    private testMatch(match, test);
    private finalizeAsyncCall();
}

==> ng2-bootstrap-1.1.0.jar: META-INF/resources/webjars/ng2-bootstrap/1.1.0/components/typeahead/typeahead.directive.d.ts <==
import { ElementRef, EventEmitter, OnInit, Renderer, TemplateRef, ViewContainerRef } from '@angular/core';
import { NgControl } from '@angular/forms';
import { TypeaheadContainerComponent } from './typeahead-container.component';
import 'rxjs/add/observable/from';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/filter';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/mergeMap';
import 'rxjs/add/operator/toArray';
import { ComponentsHelper } from '../utils/components-helper.service';
export declare class TypeaheadDirective implements OnInit {
    typeaheadLoading: EventEmitter<boolean>;
    typeaheadNoResults: EventEmitter<boolean>;
    typeaheadOnSelect: EventEmitter<{
        item: any;
    }>;
    typeahead: any;
    typeaheadMinLength: number;
    typeaheadWaitMs: number;
    typeaheadOptionsLimit: number;
    typeaheadOptionField: string;
    typeaheadAsync: boolean;
    typeaheadLatinize: boolean;
    typeaheadSingleWords: boolean;
    typeaheadWordDelimiters: string;
    typeaheadPhraseDelimiters: string;
    typeaheadItemTemplate: TemplateRef<any>;
    container: TypeaheadContainerComponent;
    isTypeaheadOptionsListActive: boolean;
    private keyUpEventEmitter;
    private _matches;
    private placement;
    private popup;
    private ngControl;
    private viewContainerRef;
    private element;
    private renderer;
    private componentsHelper;
    protected onChange(e: any): void;
    protected onFocus(): void;
    protected onBlur(): void;
    protected onKeydown(e: KeyboardEvent): void;
    constructor(control: NgControl, viewContainerRef: ViewContainerRef, element: ElementRef, renderer: Renderer, componentsHelper: ComponentsHelper);
    ngOnInit(): void;
    changeModel(value: any): void;
    matches: Array<any>;
    show(matches: Array<any>): void;
    hide(): void;
    private asyncActions();
    private syncActions();
    private prepareOption(option);
    private normalizeQuery(value);
    private testMatch(match, test);
    private finalizeAsyncCall();
}
